/*!
 * @splend-io/dsplend-js <https://github.com/splend-io/dsplend-js>
 *
 * Copyright © 2018, [Splend](http://splend.io).
 * Released under the LGPL v3 License.
 */

'use strict'

const Dsplend = require('./../../');

module.exports = () => {
  return new Promise((resolve, reject) => {
    console.log('\n\n--- TRANSACTION EXAMPLES ---\n');

  // START SETUP

    console.log('Setting up...');
    // Account is a constructor with no required inputs
    const temp = new Dsplend.Account();
    // It can also accept any account fields; the most prominant being the privateKey
    const test = new Dsplend.Account({name: 'NodeSDKTest', privateKey: '70dcae0f1020d5b35f2be2df6146b432be594407121ac7c8cb48540ecc5e7ede' });

    // Use account.init() to generate a private key
    temp.init();

    // Account objects can send tokens to other accounts directly; returning the resulting Transaciton
    let tx = test.sendTokens(temp, 50000);

    // Calling "send" on the Transaction will return the original Promise (not re-send the tx)
    tx.send()
      .then(
        (ok) => {
          // Use 'whenStatusEquals' (returns a Promise) to wait for the transaction to finish
          tx.whenStatusEquals('Ok')
            .then(
              (result) => {
                
  // END SETUP

                // Transactions may be created and executed directly
                tx = new Dsplend.Transaction({
                  from: temp,
                  to: test,
                  value: 5
                });
                console.log('New Transaction:\n' + tx + '\n');

                // Transactions can also be sent directly, which returns a Promise
                tx.send()
                  .then((result) => {
                    console.log('Transaction submission:\n' + JSON.stringify(result) + '\n');

                    // Use 'whenStatusEquals' (returns a Promise) to wait for the transaction to finish
                    tx.whenStatusEquals('Ok')
                      .then(
                        (result) => {
                          console.log('Transaction result:\n' + JSON.stringify(result) + '\n');

                          // Reset
                          temp.sendTokens(test, 50000).send()
                            .then(() => {
                              resolve();
                            })
                            .catch((e) => {
                              resolve();
                            });

                        }, (err) => {
                          console.error('Transaction status check error result:\n' + JSON.stringify(err) + '\n');
                        }
                      );
                  }, (err) => {
                    console.error('Transaction send error result:\n' + JSON.stringify(err) + '\n');
                  });


              }, (err) => {
                console.log('Setup failed!');
                console.error(err);
              }
            );
        },
        (err) => {
          console.log('Setup failed!');
          console.error(err);
        }
      );
  });
};
